@@ -1,17 +1,17 @@
-#example_rwl------------------------------------------------------------------------
+# example_rwl ------------------------------------------------------------------
 #' example_rwl
 #'
 #' An rwl object to be used in documented examples
 #'
 #' @format A data.frame with 135 years and 30 series.
 #'
-'example_rwl'
+"example_rwl"
 
-#example_iadf------------------------------------------------------------------------
+# example_iadf -----------------------------------------------------------------
 #' example_iadf
 #'
 #' An rwl object to be used in documented examples
 #'
 #' @format A data.frame with 135 years and 30 series.
 #'
-'example_iadf'
+"example_iadf"
